<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>ActionDefinition::CategoryName</name>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="63"/>
        <source>Windows</source>
        <translation>Fenêtres</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="64"/>
        <source>Device</source>
        <translation>Périphériques</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="65"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="66"/>
        <source>Internal</source>
        <translation>Interne</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="67"/>
        <source>Data</source>
        <translation>Données</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="68"/>
        <source>Procedures</source>
        <translation>Procédures</translation>
    </message>
</context>
<context>
    <name>ActionException::ExceptionActionName</name>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="43"/>
        <source>Stop execution</source>
        <translation>Stopper l&apos;exécution</translation>
    </message>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="44"/>
        <source>Skip current action</source>
        <translation>Passer l&apos;action courante</translation>
    </message>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="45"/>
        <source>Goto a line</source>
        <translation>Aller à une ligne</translation>
    </message>
</context>
<context>
    <name>ActionException::ExceptionName</name>
    <message>
        <source>Bad parameter</source>
        <translation type="obsolete">Mauvais paramètre</translation>
    </message>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="29"/>
        <source>Invalid parameter</source>
        <translation>Paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="30"/>
        <source>Code error</source>
        <translation>Erreur de code</translation>
    </message>
    <message>
        <location filename="../actiontools/actionexception.cpp" line="31"/>
        <source>Timeout</source>
        <translation>Délai écoulé</translation>
    </message>
</context>
<context>
    <name>ActionTabs</name>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="71"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="71"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
</context>
<context>
    <name>ActionTools</name>
    <message>
        <source>Standard</source>
        <translation type="obsolete">Standard</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="obsolete">Avancé</translation>
    </message>
</context>
<context>
    <name>ActionTools::ActionDefinition</name>
    <message>
        <source>Windows</source>
        <translation type="obsolete">Fenêtres</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="obsolete">Périphériques</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="obsolete">Système</translation>
    </message>
    <message>
        <source>Internal</source>
        <translation type="obsolete">Interne</translation>
    </message>
    <message>
        <source>Data</source>
        <translation type="obsolete">Données</translation>
    </message>
</context>
<context>
    <name>ActionTools::ActionException</name>
    <message>
        <source>Bad parameter</source>
        <translation type="obsolete">Mauvais paramètre</translation>
    </message>
    <message>
        <source>Code error</source>
        <translation type="obsolete">Erreur de code</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation type="obsolete">Délai</translation>
    </message>
</context>
<context>
    <name>ActionTools::ActionFactory</name>
    <message>
        <location filename="../actiontools/actionfactory.cpp" line="143"/>
        <source>%1: &quot;%2&quot;</source>
        <translation>%1 : &quot;%2&quot;</translation>
    </message>
    <message>
        <source>%1: bad definition version</source>
        <translation type="obsolete">%1 : mauvause définition de version</translation>
    </message>
    <message>
        <location filename="../actiontools/actionfactory.cpp" line="150"/>
        <source>%1: invalid definition version</source>
        <translation>%1 : définition de version incorrecte</translation>
    </message>
    <message>
        <location filename="../actiontools/actionfactory.cpp" line="170"/>
        <source>%1: &lt;b&gt;%2&lt;/b&gt; already loaded</source>
        <translation>%1 : &lt;b&gt;%2&lt;/b&gt; est déjà chargé</translation>
    </message>
    <message>
        <location filename="../actiontools/actionfactory.cpp" line="179"/>
        <source>%1: &lt;b&gt;%2&lt;/b&gt; cannot be loaded:&lt;ul&gt;&lt;li&gt;%3&lt;/ul&gt;</source>
        <translation>%1 : &lt;b&gt;%2&lt;/b&gt; ne peut pas être chargé : &lt;ul&gt;&lt;li&gt;%3&lt;/ul&gt;</translation>
    </message>
</context>
<context>
    <name>ActionTools::ActionInstance</name>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="300"/>
        <source>A variable name can only contain alphanumeric characters and cannot start with a digit.</source>
        <translation>Un nom de variable ne peut contenir que des caractères alphanumériques et ne peut pas commencer par un chiffre.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="374"/>
        <source>Integer value expected.</source>
        <translation>Valeur entière attendue.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="409"/>
        <source>Decimal value expected.</source>
        <translation>Valeur décimale attendue.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="497"/>
        <location filename="../actiontools/actioninstance.cpp" line="505"/>
        <source>&quot;%1&quot; is not a valid position.</source>
        <translation>&quot;%1&quot; n&apos;est pas une position valide.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="602"/>
        <location filename="../actiontools/actioninstance.cpp" line="610"/>
        <source>&quot;%1&quot; is not a valid color.</source>
        <translation>&quot;%1&quot; n&apos;est pas une couleur valide.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="97"/>
        <source>Unable to find any procedure named &quot;%1&quot;</source>
        <translation>Impossible de trouver une procédure nommée &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="262"/>
        <source>Invalid image.</source>
        <translation>Image invalide.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="282"/>
        <source>Unable to load image: %1</source>
        <translation>Impossible de charger l&apos;image : %1</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="808"/>
        <source>Undefined variable &quot;%1&quot;</source>
        <translation>La variable &quot;%1&quot; est inconnue</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.cpp" line="841"/>
        <source>Invalid parameter. Unable to evaluate string</source>
        <translation>Paramètre incorrect. Impossible d&apos;évaluer la chaîne de caractères</translation>
    </message>
    <message>
        <source>Bad parameter. Unable to evaluate string</source>
        <translation type="obsolete">Paramètre incorrect. Impossible d&apos;évaluer la chaîne de caractères</translation>
    </message>
    <message>
        <source>[Null]</source>
        <translation type="obsolete">[Nul]</translation>
    </message>
    <message>
        <source>[Undefined]</source>
        <translation type="obsolete">[Indéfini]</translation>
    </message>
    <message>
        <source>[Raw data]</source>
        <translation type="obsolete">[Données brutes]</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.h" line="262"/>
        <source>Please choose a value for this field.</source>
        <translation>Merci de choisir une valeur pour ce champ.</translation>
    </message>
    <message>
        <location filename="../actiontools/actioninstance.h" line="275"/>
        <source>&quot;%1&quot; is an invalid value.</source>
        <translation>&quot;%1&quot; est une valeur incorrecte.</translation>
    </message>
</context>
<context>
    <name>ActionTools::ActionInstanceExecutionHelper</name>
    <message>
        <source>[Raw data]</source>
        <translation type="obsolete">[Données brutes]</translation>
    </message>
    <message>
        <source>A variable name can only contain alphanumeric characters and cannot start with a digit.</source>
        <translation type="obsolete">Un nom de variable ne peut contenir que des caractères alphanumériques et ne peut pas démarrer par un chiffre.</translation>
    </message>
    <message>
        <source>Expected an integer value.</source>
        <translation type="obsolete">Valeur entière attendue.</translation>
    </message>
    <message>
        <source>Expected a decimal value.</source>
        <translation type="obsolete">Valeur décimale attendue.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is not a valid position.</source>
        <translation type="obsolete">&quot;%1&quot; n&apos;est pas une position valide.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is not a valid color.</source>
        <translation type="obsolete">&quot;%1&quot; n&apos;est pas une couleur valide.</translation>
    </message>
    <message>
        <source>Variable %1 not found</source>
        <translation type="obsolete">Variable %1 ne peut pas être trouvée</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is incorrect.</source>
        <translation type="obsolete">&quot;%1&quot; est incorrect.</translation>
    </message>
</context>
<context>
    <name>ActionTools::ChoosePositionPushButton</name>
    <message>
        <location filename="../actiontools/choosepositionpushbutton.cpp" line="64"/>
        <source>Target a position by clicking this button, moving the cursor to the desired position and releasing the mouse button.</source>
        <translation>Choisissez une position en cliquant sur ce bouton puis déplacez le curseur vers la position désirée et relâchez le bouton de la souris.</translation>
    </message>
    <message>
        <location filename="../actiontools/choosepositionpushbutton.cpp" line="123"/>
        <source>Choose a window</source>
        <translation>Choix de fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/choosepositionpushbutton.cpp" line="123"/>
        <source>Unable to grab the pointer.</source>
        <translation>Impossible de récupérer le curseur.</translation>
    </message>
</context>
<context>
    <name>ActionTools::ChooseWindowPushButton</name>
    <message>
        <location filename="../actiontools/choosewindowpushbutton.cpp" line="87"/>
        <source>Target a window by clicking this button, moving the cursor to the wanted window and releasing the mouse button.</source>
        <translation>Choisissez une fenêtre en cliquant sur ce bouton puis déplacez le curseur vers la fenêtre ciblée et relâchez le bouton de la souris.</translation>
    </message>
    <message>
        <location filename="../actiontools/choosewindowpushbutton.cpp" line="261"/>
        <source>Choose a window</source>
        <translation>Choix de fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/choosewindowpushbutton.cpp" line="261"/>
        <source>Unable to grab the pointer.</source>
        <translation>Impossible de récupérer le curseur.</translation>
    </message>
</context>
<context>
    <name>ActionTools::CodeDateTimeEdit</name>
    <message>
        <location filename="../actiontools/codedatetimeedit.cpp" line="127"/>
        <source>&amp;Step up</source>
        <translation>&amp;Monter</translation>
    </message>
    <message>
        <location filename="../actiontools/codedatetimeedit.cpp" line="131"/>
        <source>Step &amp;down</source>
        <translation>&amp;Descendre</translation>
    </message>
</context>
<context>
    <name>ActionTools::CodeEditorDialog</name>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="128"/>
        <source>No variables to insert</source>
        <translation>Pas de variables à insérer</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="133"/>
        <source>Insert variable</source>
        <translation>Insérer une variable</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="154"/>
        <location filename="../actiontools/codeeditordialog.cpp" line="186"/>
        <source>Syntax error check</source>
        <translation>Vérification d&apos;erreur de syntaxe</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="154"/>
        <source>No syntax errors where found.</source>
        <translation>Aucune erreur de syntaxe n&apos;a été trouvée.</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="182"/>
        <source>Syntax error detected.</source>
        <translation>Des erreurs de syntaxe ont été trouvées.</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.cpp" line="184"/>
        <source>Syntax error detected: %1</source>
        <translation>Erreur de syntaxe détectée : %1</translation>
    </message>
</context>
<context>
    <name>ActionTools::CodeLineEdit</name>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="53"/>
        <source>Set to text/code</source>
        <translation>Changer en texte/code</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="54"/>
        <source>Open editor</source>
        <translation>Ouvrir éditeur</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="80"/>
        <source>Click here to switch text/code</source>
        <translation>Cliquez ici pour passer en mode texte/code</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="84"/>
        <source>Click here to open the editor</source>
        <translation>Cliquez ici pour ouvrir l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="88"/>
        <source>Click here to insert a variable or a resource</source>
        <translation>Cliquez ici pour insérer une variable ou une ressource</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="268"/>
        <source>Insert variable/resource</source>
        <translation>Insérer une variable/ressource</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="268"/>
        <source>Inserting a variable or a resource will replace the current parameter value.
Are you sure?</source>
        <translation>Insérer une variable ou une ressource va remplacer la valeur actuelle du paramètre.
Êtes-vous sûr ?</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="306"/>
        <location filename="../actiontools/codelineedit.cpp" line="335"/>
        <source>Cannot insert in a multiline parameter</source>
        <translation>Impossible d&apos;insérer dans un paramètre multiligne</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="343"/>
        <source>Insert resource</source>
        <translation>Insérer une ressource</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="346"/>
        <source>No resources to insert</source>
        <translation>Aucune ressource à insérer</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="460"/>
        <source>Multiline, double-click to edit</source>
        <translation>Multiligne, double-cliquez pour éditer</translation>
    </message>
    <message>
        <source>Click here to insert a variable</source>
        <translation type="obsolete">Cliquez ici pour insérer une variable</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="315"/>
        <source>Insert variable</source>
        <translation>Insérer une variable</translation>
    </message>
    <message>
        <location filename="../actiontools/codelineedit.cpp" line="319"/>
        <source>No variables to insert</source>
        <translation>Pas de variables à insérer</translation>
    </message>
    <message>
        <source>Double-click to edit</source>
        <translation type="obsolete">Double-cliquez pour éditer</translation>
    </message>
</context>
<context>
    <name>ActionTools::CodeSpinBox</name>
    <message>
        <location filename="../actiontools/codespinbox.cpp" line="156"/>
        <source>&amp;Step up</source>
        <translation>&amp;Monter</translation>
    </message>
    <message>
        <location filename="../actiontools/codespinbox.cpp" line="160"/>
        <source>Step &amp;down</source>
        <translation>&amp;Descendre</translation>
    </message>
</context>
<context>
    <name>ActionTools::ConsoleWidget</name>
    <message>
        <location filename="../actiontools/consolewidget.cpp" line="124"/>
        <source>Execution started at %1</source>
        <translation>Exécution démarrée à %1</translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/consolewidget.cpp" line="136"/>
        <source>%n day(s) </source>
        <translation>
            <numerusform>%n jour </numerusform>
            <numerusform>%n jours </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/consolewidget.cpp" line="146"/>
        <source>%n hour(s) </source>
        <translation>
            <numerusform>%n heure </numerusform>
            <numerusform>%n heures </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/consolewidget.cpp" line="148"/>
        <source>%n minute(s) </source>
        <translation>
            <numerusform>%n minute </numerusform>
            <numerusform>%n minutes </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/consolewidget.cpp" line="150"/>
        <source>%n second(s) </source>
        <translation>
            <numerusform>%n seconde </numerusform>
            <numerusform>%n secondes </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/consolewidget.cpp" line="155"/>
        <source>%n millisecond(s)</source>
        <translation>
            <numerusform>%n milliseconde</numerusform>
            <numerusform>%n millisecondes</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../actiontools/consolewidget.cpp" line="157"/>
        <source>Execution ended at %1
(%2)</source>
        <translation>Exécution terminée à %1
(%2)</translation>
    </message>
    <message>
        <location filename="../actiontools/consolewidget.cpp" line="210"/>
        <source>
Double-click to show</source>
        <translation>
Double-cliquez pour afficher</translation>
    </message>
</context>
<context>
    <name>ActionTools::OpenCVAlgorithms</name>
    <message>
        <location filename="../actiontools/opencvalgorithms.cpp" line="54"/>
        <source>FindSubImage is already running</source>
        <translation>Recherche via FindSubImage en cours</translation>
    </message>
    <message>
        <location filename="../actiontools/opencvalgorithms.cpp" line="126"/>
        <source>Source images must be larger than target image</source>
        <translation>Les images source doivent être plus grandes que l&apos;image cible</translation>
    </message>
    <message>
        <location filename="../actiontools/opencvalgorithms.cpp" line="134"/>
        <source>Source images and target image must have same depth</source>
        <translation>Les images source et l&apos;image cible doivent avoir la même profondeur</translation>
    </message>
    <message>
        <location filename="../actiontools/opencvalgorithms.cpp" line="142"/>
        <source>Source images and target image must have same number of channels</source>
        <translation>Les images source et l&apos;image cible doivent avoir le même nombre de canaux</translation>
    </message>
    <message>
        <source>Source image must be larger than target image</source>
        <translation type="obsolete">L&apos;image source doit être plus grande que l&apos;image cible</translation>
    </message>
    <message>
        <source>Source image and target image must have same depth</source>
        <translation type="obsolete">L&apos;image source et l&apos;image cible doivent avoir la même profondeur</translation>
    </message>
    <message>
        <source>Source image and target image must have same number of channels</source>
        <translation type="obsolete">L&apos;image source et l&apos;image cible doivent avoir le même nombre de canaux</translation>
    </message>
    <message>
        <location filename="../actiontools/opencvalgorithms.cpp" line="325"/>
        <source>OpenCV exception: %1</source>
        <translation>Exception OpenCV : %1</translation>
    </message>
</context>
<context>
    <name>ActionTools::PositionParameterDefinition</name>
    <message>
        <location filename="../actiontools/positionparameterdefinition.cpp" line="49"/>
        <source>pixels</source>
        <translation>pixels</translation>
    </message>
    <message>
        <location filename="../actiontools/positionparameterdefinition.cpp" line="49"/>
        <source>percents</source>
        <translation>pourcentage</translation>
    </message>
</context>
<context>
    <name>ActionTools::SaveScreenshotWizardPage</name>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.cpp" line="59"/>
        <source>Select the file where to save the screenshot</source>
        <translation>Sélectionnez le fichier où enregistrer la capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.cpp" line="60"/>
        <source>Images (*.png *.jpg *.jpeg *.bmp *.ppm *.xbm *.xpm);;All files (*.*)</source>
        <translation>Images (*.png *.jpg *.jpeg *.bmp *.ppm *.xbm *.xpm);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.cpp" line="70"/>
        <source>Failed to save the screenshot</source>
        <translation>Impossible d&apos;enregistrer la capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.cpp" line="70"/>
        <source>Failed to save the screenshot.</source>
        <translation>Impossible d&apos;enregistrer la capture d&apos;écran.</translation>
    </message>
</context>
<context>
    <name>ActionTools::ScreenPositionWidget</name>
    <message>
        <location filename="../actiontools/screenpositionwidget.cpp" line="48"/>
        <source>Screen %1</source>
        <translation>Écran %1</translation>
    </message>
</context>
<context>
    <name>ActionTools::ScreenshotWizard</name>
    <message>
        <location filename="../actiontools/screenshotwizard.cpp" line="33"/>
        <source>Screenshot wizard</source>
        <translation>Assistant capture d&apos;écran</translation>
    </message>
</context>
<context>
    <name>ActionTools::ScreenshotWizardPage</name>
    <message>
        <location filename="../actiontools/screenshotwizardpage.cpp" line="45"/>
        <source>All screens</source>
        <translation>Tous les écrans</translation>
    </message>
    <message>
        <location filename="../actiontools/screenshotwizardpage.cpp" line="48"/>
        <source>Screen %1</source>
        <translation>Écran %1</translation>
    </message>
</context>
<context>
    <name>ActionTools::Script</name>
    <message>
        <location filename="../actiontools/script.cpp" line="200"/>
        <source>Writing...</source>
        <translation>Écriture...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="208"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="210"/>
        <source>GNU/Linux</source>
        <translation>GNU/Linux</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="213"/>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="216"/>
        <source>Mac</source>
        <translation>Mac</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="247"/>
        <source>Writing parameters...</source>
        <translation>Écriture des paramètres...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="267"/>
        <source>Writing resources...</source>
        <translation>Écriture des ressources...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="288"/>
        <source>Writing actions...</source>
        <translation>Écriture des actions...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="363"/>
        <source>Reading schema...</source>
        <translation>Lecture du schéma...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="369"/>
        <source>Listing file content...</source>
        <translation>Création de la liste de contenu du fichier...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="441"/>
        <source>Reading content...</source>
        <translation>Lecture du contenu...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="496"/>
        <source>Reading parameters...</source>
        <translation>Lecture des paramètres...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="516"/>
        <source>Reading resources...</source>
        <translation>Lecture des ressources...</translation>
    </message>
    <message>
        <location filename="../actiontools/script.cpp" line="565"/>
        <source>Reading actions...</source>
        <translation>Lecture des actions...</translation>
    </message>
</context>
<context>
    <name>ActionTools::TargetWindow</name>
    <message>
        <location filename="../actiontools/targetwindow.cpp" line="158"/>
        <location filename="../actiontools/targetwindow.cpp" line="166"/>
        <source>Choose a screen rectangle</source>
        <translation>Choix d&apos;un rectangle sur l&apos;écran</translation>
    </message>
    <message>
        <location filename="../actiontools/targetwindow.cpp" line="158"/>
        <location filename="../actiontools/targetwindow.cpp" line="166"/>
        <source>Unable to grab the pointer.</source>
        <translation>Impossible de prendre le contrôle du curseur.</translation>
    </message>
</context>
<context>
    <name>ActionTools::VariableLineEdit</name>
    <message>
        <location filename="../actiontools/variablelineedit.cpp" line="58"/>
        <source>Cannot insert resources here</source>
        <translation>Impossible d&apos;insérer des ressources ici</translation>
    </message>
</context>
<context>
    <name>BooleanEdit</name>
    <message>
        <location filename="../actiontools/booleanedit.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
</context>
<context>
    <name>Code</name>
    <message>
        <source>Unable to open the process</source>
        <translation type="obsolete">Impossible d&apos;ouvrir le processus</translation>
    </message>
    <message>
        <source>Unable to retrieve the process priority</source>
        <translation type="obsolete">Impossible de récupérer la priorité du processus</translation>
    </message>
    <message>
        <source>This is not available under your operating system</source>
        <translation type="obsolete">Ceci n&apos;est pas disponible sous votre système d&apos;exploitation</translation>
    </message>
</context>
<context>
    <name>Code::Algorithms</name>
    <message>
        <location filename="../actiontools/code/algorithms.cpp" line="89"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::Color</name>
    <message>
        <location filename="../actiontools/code/color.cpp" line="41"/>
        <location filename="../actiontools/code/color.cpp" line="228"/>
        <source>Invalid color name</source>
        <translation>Nom de couleur incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/color.cpp" line="53"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/color.cpp" line="64"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::Image</name>
    <message>
        <location filename="../actiontools/code/image.cpp" line="65"/>
        <location filename="../actiontools/code/image.cpp" line="449"/>
        <location filename="../actiontools/code/image.cpp" line="505"/>
        <location filename="../actiontools/code/image.cpp" line="541"/>
        <location filename="../actiontools/code/image.cpp" line="578"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="69"/>
        <location filename="../actiontools/code/image.cpp" line="112"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="95"/>
        <source>Invalid window</source>
        <translation>Fenêtre invalide</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="121"/>
        <source>Invalid screen index</source>
        <translation>Index d&apos;écran non valide</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="252"/>
        <source>Unable to set the image data</source>
        <translation>Impossible de changer les données de l&apos;image</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="270"/>
        <source>Unable to get the image data</source>
        <translation>Impossible de récupérer les données de l&apos;image</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="432"/>
        <location filename="../actiontools/code/image.cpp" line="475"/>
        <location filename="../actiontools/code/image.cpp" line="531"/>
        <location filename="../actiontools/code/image.cpp" line="568"/>
        <source>Error while searching for a sub-image: %1</source>
        <translation>Erreur lors de la recherche d&apos;une sous-image : %1</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="516"/>
        <location filename="../actiontools/code/image.cpp" line="552"/>
        <source>Parameter &quot;callback&quot; is not a function</source>
        <translation>Le paramètre &quot;callback&quot; n&apos;est pas une fonction</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="62"/>
        <location filename="../actiontools/code/image.cpp" line="281"/>
        <source>Unable to load image from file %1</source>
        <translation>Impossible de charger l&apos;image à partir du fichier %1</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="292"/>
        <source>Unable to save image to file %1</source>
        <translation>Impossible de sauvegarder l&apos;image dans le fichier %1</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="304"/>
        <source>Unable to apply filter</source>
        <translation>Impossible d&apos;appliquer le filtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/image.cpp" line="341"/>
        <source>Cannot set filter option %1 %2</source>
        <translation>Impossible de changer les options du filtre %1 %2</translation>
    </message>
</context>
<context>
    <name>Code::Point</name>
    <message>
        <location filename="../actiontools/code/point.cpp" line="41"/>
        <location filename="../actiontools/code/point.cpp" line="73"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/point.cpp" line="48"/>
        <location filename="../actiontools/code/point.cpp" line="80"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::ProcessHandle</name>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="52"/>
        <location filename="../actiontools/code/processhandle.cpp" line="81"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="183"/>
        <location filename="../actiontools/code/processhandle.cpp" line="216"/>
        <source>Unable to open the process</source>
        <translation>Impossible d&apos;ouvrir le processus</translation>
    </message>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="190"/>
        <source>Unable to retrieve the executable filename</source>
        <translation>Impossible d&apos;obtenir le nom de l&apos;exécutable</translation>
    </message>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="202"/>
        <source>Failed to get the process command</source>
        <translation>Impossible de récupérer la commande de processus</translation>
    </message>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="238"/>
        <source>Unable to retrieve the process priority</source>
        <translation>Impossible de récupérer la priorité du processus</translation>
    </message>
    <message>
        <location filename="../actiontools/code/processhandle.cpp" line="242"/>
        <source>This is not available under your operating system</source>
        <translation>Ceci n&apos;est pas disponible sous votre système d&apos;exploitation</translation>
    </message>
</context>
<context>
    <name>Code::RawData</name>
    <message>
        <location filename="../actiontools/code/rawdata.cpp" line="40"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/rawdata.cpp" line="44"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::Rect</name>
    <message>
        <location filename="../actiontools/code/rect.cpp" line="43"/>
        <location filename="../actiontools/code/rect.cpp" line="78"/>
        <location filename="../actiontools/code/rect.cpp" line="312"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/rect.cpp" line="53"/>
        <location filename="../actiontools/code/rect.cpp" line="87"/>
        <location filename="../actiontools/code/rect.cpp" line="323"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::Size</name>
    <message>
        <location filename="../actiontools/code/size.cpp" line="41"/>
        <location filename="../actiontools/code/size.cpp" line="73"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/size.cpp" line="48"/>
        <location filename="../actiontools/code/size.cpp" line="80"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
</context>
<context>
    <name>Code::Window</name>
    <message>
        <location filename="../actiontools/code/window.cpp" line="47"/>
        <location filename="../actiontools/code/window.cpp" line="76"/>
        <source>Incorrect parameter type</source>
        <translation>Type de paramètre incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="51"/>
        <location filename="../actiontools/code/window.cpp" line="80"/>
        <source>Incorrect parameter count</source>
        <translation>Nombre de paramètres incorrect</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="120"/>
        <source>Invalid process handle</source>
        <translation>Processus invalide</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="311"/>
        <source>Unable to close the window</source>
        <translation>Impossible de fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="322"/>
        <source>Unable to kill the window creator</source>
        <translation>Impossible de fermer de créateur de la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="333"/>
        <source>Unable to set the window foreground</source>
        <translation>Impossible de placer la fenêtre en premier plan</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="344"/>
        <source>Unable to minimize the window</source>
        <translation>Impossible de minimiser la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="355"/>
        <source>Unable to maximize the window</source>
        <translation>Impossible de maximiser la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="366"/>
        <source>Unable to move the window</source>
        <translation>Impossible de déplacer la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="377"/>
        <source>Unable to resize the window</source>
        <translation>Impossible de redimensionner la fenêtre</translation>
    </message>
    <message>
        <location filename="../actiontools/code/window.cpp" line="386"/>
        <source>Invalid window</source>
        <translation>Fenêtre invalide</translation>
    </message>
</context>
<context>
    <name>CodeEditorDialog</name>
    <message>
        <source>Code editor</source>
        <translation type="obsolete">Éditeur de code</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.ui" line="14"/>
        <source>Text/Code editor</source>
        <translation>Éditeur de texte/code</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.ui" line="27"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.ui" line="40"/>
        <source>Code</source>
        <translation>Code</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.ui" line="60"/>
        <source>Insert...</source>
        <translation>Insérer...</translation>
    </message>
    <message>
        <location filename="../actiontools/codeeditordialog.ui" line="86"/>
        <source>Check syntax</source>
        <translation>Vérifier la syntaxe</translation>
    </message>
</context>
<context>
    <name>ColorEdit</name>
    <message>
        <location filename="../actiontools/coloredit.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../actiontools/coloredit.ui" line="47"/>
        <source>Choose...</source>
        <translation>Choisir...</translation>
    </message>
</context>
<context>
    <name>ConsoleWidget</name>
    <message>
        <location filename="../actiontools/consolewidget.ui" line="14"/>
        <source>Console</source>
        <translation>Console</translation>
    </message>
    <message>
        <location filename="../actiontools/consolewidget.ui" line="63"/>
        <source>Clear</source>
        <translation>Vider</translation>
    </message>
</context>
<context>
    <name>FileEdit</name>
    <message>
        <location filename="../actiontools/fileedit.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../actiontools/fileedit.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>IfActionParameterDefinition::actions</name>
    <message>
        <location filename="../actiontools/ifactionparameterdefinition.cpp" line="38"/>
        <source>Do nothing</source>
        <translation>Ne rien faire</translation>
    </message>
    <message>
        <location filename="../actiontools/ifactionparameterdefinition.cpp" line="39"/>
        <source>Goto line</source>
        <translation>Aller à une ligne</translation>
    </message>
    <message>
        <location filename="../actiontools/ifactionparameterdefinition.cpp" line="40"/>
        <source>Run code</source>
        <translation>Exécuter code</translation>
    </message>
    <message>
        <location filename="../actiontools/ifactionparameterdefinition.cpp" line="41"/>
        <source>Call procedure</source>
        <translation>Appeler une procédure</translation>
    </message>
</context>
<context>
    <name>ItemListWidget</name>
    <message>
        <location filename="../actiontools/itemlistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../actiontools/itemlistwidget.ui" line="44"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../actiontools/itemlistwidget.ui" line="51"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../actiontools/itemlistwidget.ui" line="71"/>
        <source>Move up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../actiontools/itemlistwidget.ui" line="78"/>
        <source>Move down</source>
        <translation>Descendre</translation>
    </message>
</context>
<context>
    <name>PointListWidget</name>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="31"/>
        <source>Add point</source>
        <translation>Ajouter point</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="58"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="65"/>
        <source>Clear</source>
        <translation>Vider</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="96"/>
        <source>X</source>
        <translation>Abscisse</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="101"/>
        <source>Y</source>
        <translation>Ordonnée</translation>
    </message>
    <message>
        <location filename="../actiontools/pointlistwidget.ui" line="111"/>
        <source>Choose path:</source>
        <translation>Choisir chemin :</translation>
    </message>
</context>
<context>
    <name>PositionEdit</name>
    <message>
        <location filename="../actiontools/positionedit.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Windows</source>
        <translation type="obsolete">Fenêtres</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="obsolete">Périphériques</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="obsolete">Système</translation>
    </message>
    <message>
        <source>Internal</source>
        <translation type="obsolete">Interne</translation>
    </message>
    <message>
        <source>Data</source>
        <translation type="obsolete">Données</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.cpp" line="105"/>
        <source>missing XTest extension</source>
        <translation>extension XTest manquante</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation type="obsolete">Standard</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="obsolete">Avancé</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.h" line="52"/>
        <source>No description</source>
        <translation>Pas de description</translation>
    </message>
    <message>
        <location filename="../actiontools/actiondefinition.h" line="57"/>
        <source>The Actionaz Team</source>
        <translation>L&apos;équipe d&apos;Actionaz</translation>
    </message>
    <message>
        <source>Bad parameter</source>
        <translation type="obsolete">Mauvais paramètre</translation>
    </message>
    <message>
        <source>Code error</source>
        <translation type="obsolete">Erreur de code</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation type="obsolete">Délai</translation>
    </message>
    <message>
        <source>Stop execution</source>
        <translation type="obsolete">Stopper l&apos;exécution</translation>
    </message>
    <message>
        <source>Skip current action</source>
        <translation type="obsolete">Passer l&apos;action courante</translation>
    </message>
    <message>
        <source>Goto a line</source>
        <translation type="obsolete">Aller à une ligne</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="obsolete">Ne rien faire</translation>
    </message>
    <message>
        <source>Goto line</source>
        <translation type="obsolete">Aller à une ligne</translation>
    </message>
    <message>
        <location filename="../actiontools/ifactionparameterdefinition.cpp" line="69"/>
        <source>Wait</source>
        <translation>Attendre</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="47"/>
        <source>Left Shift</source>
        <translation>Shift gauche</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="47"/>
        <source>Right Shift</source>
        <translation>Shift droit</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="47"/>
        <source>Left Control</source>
        <translation>Contrôle gauche</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="47"/>
        <source>Right Control</source>
        <translation>Contrôle droit</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="48"/>
        <source>Left Alt</source>
        <translation>Alt gauche</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="48"/>
        <source>Right Alt</source>
        <translation>Alt droit</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="50"/>
        <source>Left Windows</source>
        <translation>Windows gauche</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="50"/>
        <source>Right Windows</source>
        <translation>Windows droit</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="52"/>
        <source>Left Meta</source>
        <translation>Méta gauche</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="52"/>
        <source>Right Meta</source>
        <translation>Méta droit</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Alt Gr</source>
        <translation>Alt Gr</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Numpad 0</source>
        <translation>Pavé numérique 0</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Numpad 1</source>
        <translation>Pavé numérique 1</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Numpad 2</source>
        <translation>Pavé numérique 2</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Numpad 3</source>
        <translation>Pavé numérique 3</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="54"/>
        <source>Numpad 4</source>
        <translation>Pavé numérique 4</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="55"/>
        <source>Numpad 5</source>
        <translation>Pavé numérique 5</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="55"/>
        <source>Numpad 6</source>
        <translation>Pavé numérique 7</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="55"/>
        <source>Numpad 7</source>
        <translation>Pavé numérique 7</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="55"/>
        <source>Numpad 8</source>
        <translation>Pavé numérique 8</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="55"/>
        <source>Numpad 9</source>
        <translation>Pavé numérique 9</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad *</source>
        <translation>Pavé numérique *</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad +</source>
        <translation>Pavé numérique +</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad Separator</source>
        <translation>Pavé numérique séparateur</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad -</source>
        <translation>Pavé numérique -</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad .</source>
        <translation>Pavé numérique .</translation>
    </message>
    <message>
        <location filename="../actiontools/keyinput.cpp" line="56"/>
        <source>Numpad /</source>
        <translation>Pavé numérique /</translation>
    </message>
    <message>
        <location filename="../actiontools/linecombobox.cpp" line="37"/>
        <source>Labels</source>
        <translation>Labels</translation>
    </message>
    <message>
        <location filename="../actiontools/linecombobox.cpp" line="43"/>
        <source>Lines</source>
        <translation>Lignes</translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/gaussfilter.h" line="97"/>
        <source>A gaussian blur filter</source>
        <comment>GaussBlurFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/punchfilter.h" line="63"/>
        <source>A parametrized circular pinch/punch filter</source>
        <comment>PunchFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilter.cpp" line="232"/>
        <source>The filter has no description.</source>
        <comment>QtImageFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="67"/>
        <source>Blurs the image</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="96"/>
        <source>Sharpens the image</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="109"/>
        <source>Sharpens the image more</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="122"/>
        <source>Sharpens the image even more</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="137"/>
        <source>Creates big edges</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="150"/>
        <source>Creates an emboss effect on the image, resulting in a greyish image</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="163"/>
        <source>Creates an emboss effect on the image, while keeping most of the colours</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="176"/>
        <source>Creates a filter that enables you to detect edges easily.</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="187"/>
        <source>Negates color channel(s).</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="198"/>
        <source>Removes channel(s). I.e sets the value of each channel it is processing to 0.</source>
        <comment>ConvolutionFilter</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qtimagefilters/qtimagefilterfactory.cpp" line="209"/>
        <source>Generic convolutionfilter.</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../actiontools/numberformat.cpp" line="30"/>
        <source>%n byte(s)</source>
        <translation>
            <numerusform>%n octet(s)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../actiontools/numberformat.cpp" line="32"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../actiontools/numberformat.cpp" line="32"/>
        <source>MB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../actiontools/numberformat.cpp" line="32"/>
        <source>GB</source>
        <translation>Go</translation>
    </message>
    <message>
        <location filename="../actiontools/numberformat.cpp" line="32"/>
        <source>TB</source>
        <translation>To</translation>
    </message>
</context>
<context>
    <name>QxtCommandOptions</name>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="101"/>
        <source>sets the application GUI style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="102"/>
        <source>sets the application stylesheet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="103"/>
        <source>restores the application from an earlier session</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="104"/>
        <source>displays debugging information about widgets</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="105"/>
        <source>use right-to-left layout</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="107"/>
        <source>never grab the mouse or keyboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="110"/>
        <source>grab the mouse/keyboard even in a debugger</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="111"/>
        <source>run in synchronous mode for debugging</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="114"/>
        <source>use Direct3D by default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="117"/>
        <source>sets the X11 display</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="118"/>
        <source>sets the geometry of the first window</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="120"/>
        <source>sets the default font</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="122"/>
        <source>sets the default background color</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="124"/>
        <source>sets the default foreground color</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="126"/>
        <source>sets the default button color</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="127"/>
        <source>sets the application name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="128"/>
        <source>sets the application title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="129"/>
        <source>sets the X11 visual type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="130"/>
        <source>limit the number of colors on an 8-bit display</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="131"/>
        <source>use a private color map</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="132"/>
        <source>sets the input method server</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="133"/>
        <source>disable the X Input Method</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="134"/>
        <source>sets the style used by the input method</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="235"/>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="249"/>
        <source>option &quot;%1&quot; not found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="384"/>
        <source>Short options cannot have optional parameters</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="396"/>
        <source>positional() called before parse()</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="410"/>
        <source>unrecognized() called before parse()</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="423"/>
        <source>count() called before parse()</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="443"/>
        <source>value() called before parse()</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="458"/>
        <source>parameters() called before parse()</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="748"/>
        <source>unrecognized parameters: </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../actiontools/qxtcommandoptions/qxtcommandoptions.cpp" line="751"/>
        <source>%1 requires a parameter</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Resource::typeNames</name>
    <message>
        <location filename="../actiontools/resource.cpp" line="26"/>
        <source>Binary</source>
        <translation>Binaire</translation>
    </message>
    <message>
        <location filename="../actiontools/resource.cpp" line="27"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../actiontools/resource.cpp" line="28"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
</context>
<context>
    <name>ResourceNameDialog</name>
    <message>
        <location filename="../actiontools/resourcenamedialog.ui" line="14"/>
        <source>Resource name</source>
        <translation>Nom de la ressource</translation>
    </message>
    <message>
        <location filename="../actiontools/resourcenamedialog.ui" line="30"/>
        <source>Resource name:</source>
        <translation>Nom de la ressource :</translation>
    </message>
</context>
<context>
    <name>SaveScreenshotWizardPage</name>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation>PageD&apos;Assistant</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.ui" line="20"/>
        <source>Save to file</source>
        <translation>Enregistrer dans un fichier</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.ui" line="27"/>
        <source>Save to resource</source>
        <translation>Enregistrer dans une ressource</translation>
    </message>
    <message>
        <location filename="../actiontools/savescreenshotwizardpage.ui" line="34"/>
        <source>Save to clipboard</source>
        <translation>Enregistrer dans le presse-papiers</translation>
    </message>
</context>
<context>
    <name>ScreenshotWizardPage</name>
    <message>
        <location filename="../actiontools/screenshotwizardpage.ui" line="14"/>
        <source>WizardPage</source>
        <translation>PageD&apos;Assistant</translation>
    </message>
    <message>
        <location filename="../actiontools/screenshotwizardpage.ui" line="25"/>
        <source>Capture whole screen:</source>
        <translation>Capturer tout l&apos;écran :</translation>
    </message>
    <message>
        <location filename="../actiontools/screenshotwizardpage.ui" line="37"/>
        <location filename="../actiontools/screenshotwizardpage.ui" line="53"/>
        <source>Capture</source>
        <translation>Capturer</translation>
    </message>
    <message>
        <location filename="../actiontools/screenshotwizardpage.ui" line="46"/>
        <source>Capture screen part:</source>
        <translation>Capturer une partie de l&apos;écran :</translation>
    </message>
    <message>
        <location filename="../actiontools/screenshotwizardpage.ui" line="60"/>
        <source>Capture window:</source>
        <translation>Capturer une fenêtre :</translation>
    </message>
</context>
<context>
    <name>WindowEdit</name>
    <message>
        <location filename="../actiontools/windowedit.ui" line="14"/>
        <source>Form</source>
        <translation>Formulaire</translation>
    </message>
</context>
<context>
    <name>tabs</name>
    <message>
        <source>Standard</source>
        <translation type="obsolete">Standard</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="obsolete">Avancé</translation>
    </message>
</context>
</TS>
